==> haskell-optics-th-0.4.1-156-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-3PiojQalny3JDHtOkjOEha
key:                  optics-th-0.4.1-3PiojQalny3JDHtOkjOEha
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  57a3027d16c6dc5f6a8b54327a6d21db
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-3PiojQalny3JDHtOkjOEha
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-CR9FKpPQYOw8WAQKAI7qy2
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-th-0.4.1-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-8t6ZXoK5E52JjPkZA6bWzJ
key:                  optics-th-0.4.1-8t6ZXoK5E52JjPkZA6bWzJ
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  b39bbcd0c279136543fb063efe8056eb
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-8t6ZXoK5E52JjPkZA6bWzJ
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    optics-core-0.4.1.1-EQqdiMTyppaITRJXyIj40k
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
